@@ -445,8 +445,7 @@ pub struct KeyTemplate {
 /// to this serialized proto contains also type_url identifying the
 /// definition of *Key-proto (as in KeyFormat-message), and some extra metadata
 /// about the type key material.
-#[derive(serde::Deserialize, serde::Serialize)]
-#[serde(rename_all = "camelCase")]
+#[derive(serde::Deserialize, serde::Serialize)] #[serde(rename_all = "camelCase")]
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct KeyData {
     /// Required.
@@ -483,8 +482,7 @@ pub mod key_data {
 /// to enable key rotation.  The keys in a keyset can belong to different
 /// implementations/key types, but must all implement the same primitive.
 /// Any given keyset (and any given key) can be used for one primitive only.
-#[derive(serde::Deserialize, serde::Serialize)]
-#[serde(rename_all = "camelCase")]
+#[derive(serde::Deserialize, serde::Serialize)] #[serde(rename_all = "camelCase")]
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Keyset {
     /// Identifies key used to generate new crypto data (encrypt, sign).
@@ -498,8 +496,7 @@ pub struct Keyset {
 }
 /// Nested message and enum types in `Keyset`.
 pub mod keyset {
-    #[derive(serde::Serialize, serde::Deserialize)]
-    #[serde(rename_all = "camelCase")]
+    #[derive(serde::Serialize, serde::Deserialize)] #[serde(rename_all = "camelCase")]
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct Key {
         /// Contains the actual, instantiation specific key proto.
@@ -523,8 +520,7 @@ pub mod keyset {
 /// Represents a "safe" Keyset that doesn't contain any actual key material,
 /// thus can be used for logging or monitoring. Most fields are copied from
 /// Keyset.
-#[derive(serde::Deserialize, serde::Serialize)]
-#[serde(rename_all = "camelCase")]
+#[derive(serde::Deserialize, serde::Serialize)] #[serde(rename_all = "camelCase")]
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct KeysetInfo {
     /// See Keyset.primary_key_id.
@@ -537,8 +533,7 @@ pub struct KeysetInfo {
 }
 /// Nested message and enum types in `KeysetInfo`.
 pub mod keyset_info {
-    #[derive(serde::Serialize, serde::Deserialize)]
-    #[serde(rename_all = "camelCase")]
+    #[derive(serde::Serialize, serde::Deserialize)] #[serde(rename_all = "camelCase")]
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct KeyInfo {
         /// the type url of this key,
@@ -559,8 +554,7 @@ pub mod keyset_info {
     }
 }
 /// Represents a keyset that is encrypted with a master key.
-#[derive(serde::Deserialize, serde::Serialize)]
-#[serde(rename_all = "camelCase")]
+#[derive(serde::Deserialize, serde::Serialize)] #[serde(rename_all = "camelCase")]
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct EncryptedKeyset {
     /// Required.
@@ -587,7 +581,10 @@ pub enum KeyStatusType {
 /// entirely by the primitive, but the prefix has to be one of the following
 /// 4 types:
 ///   - Legacy: prefix is 5 bytes, starts with \x00 and followed by a 4-byte
-///             key id that is computed from the key material.
+///             key id that is computed from the key material. In addition to
+///             that, signature schemes and MACs will add a \x00 byte to the
+///             end of the data being signed / MACed when operating on keys
+///             with this OutputPrefixType.
 ///   - Crunchy: prefix is 5 bytes, starts with \x00 and followed by a 4-byte
 ///             key id that is generated randomly.
 ///   - Tink  : prefix is 5 bytes, starts with \x01 and followed by 4-byte
@@ -600,9 +597,6 @@ pub enum OutputPrefixType {
     Tink = 1,
     Legacy = 2,
     Raw = 3,
-    /// CRUNCHY is like LEGACY, but with two differences:
-    ///   - Its key id is generated randomly (like TINK)
-    ///   - Its signature schemes don't append zero to sign messages
     Crunchy = 4,
 }
 // Protos for keys for ECIES with HKDF and AEAD encryption.
@@ -797,6 +791,18 @@ pub struct JwtHmacKey {
     pub algorithm: i32,
     #[prost(bytes="vec", tag="3")]
     pub key_value: ::prost::alloc::vec::Vec<u8>,
+    #[prost(message, optional, tag="4")]
+    pub custom_kid: ::core::option::Option<jwt_hmac_key::CustomKid>,
+}
+/// Nested message and enum types in `JwtHmacKey`.
+pub mod jwt_hmac_key {
+    /// Optional, custom kid header value to be used with "RAW" keys.
+    /// "TINK" keys with this value set will be rejected.
+    #[derive(Clone, PartialEq, ::prost::Message)]
+    pub struct CustomKid {
+        #[prost(string, tag="1")]
+        pub value: ::prost::alloc::string::String,
+    }
 }
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct JwtHmacKeyFormat {
